@@ -28,6 +28,7 @@ impl Cli {
         let mut processor: Processor;
         let mut error_option : Option<WriteOption> = Some(WriteOption::Stdout);
         let purge_option = args.is_present("purge");
+        let greedy_option = args.is_present("greedy");
         // ========
         // Sub options
         // Set error write option
@@ -65,12 +66,14 @@ impl Cli {
                 processor = Processor::new(WriteOption::File(out_file), error_option, newline);
                 processor.add_custom_rules(rule_file.rules);
                 if purge_option { processor.set_purge() };
+                if greedy_option { processor.set_greedy() };
             }
             // Write to standard output
             else { 
                 processor = Processor::new(WriteOption::Stdout, error_option, newline); 
                 processor.add_custom_rules(rule_file.rules);
                 if purge_option { processor.set_purge() };
+                if greedy_option { processor.set_greedy() };
             }
 
             for file in files {
@@ -90,10 +93,12 @@ impl Cli {
                 processor = Processor::new(WriteOption::File(out_file), error_option, newline);
                 processor.add_custom_rules(rule_file.rules);
                 if purge_option { processor.set_purge() };
+                if greedy_option { processor.set_greedy() };
             } else { 
                 processor = Processor::new(WriteOption::Stdout, error_option, newline); 
                 processor.add_custom_rules(rule_file.rules);
                 if purge_option { processor.set_purge() };
+                if greedy_option { processor.set_greedy() };
             }
 
             processor.from_stdin(false)?;
@@ -112,12 +117,13 @@ impl Cli {
 
     fn args_builder() -> clap::ArgMatches {
         clap_app!(R4d =>
-            (version: "0.3.2")
+            (version: "0.4.2")
             (author: "Simon Creek <simoncreek@tutanota.com>")
             (about: "R4d is a modern macro processor made with rust")
             (@arg FILE: ... "Files to execute processing")
             (@arg out: -o --out +takes_value "File to print out macro")
             (@arg err: -e --err +takes_value "File to save logs")
+            (@arg greedy: -g "Make all macro invocation greedy")
             (@arg melt: ... -m +takes_value "Frozen file to reads")
             (@arg freeze: -f +takes_value "Freeze to file")
             (@arg purge: -p "Purge unused macros")
