@@ -84,6 +84,8 @@ impl ErrorLogger{
 
 #[derive(Error, Debug)]
 pub enum RadError {
+    #[error("Invalid environment name : {0}")]
+    EnvError(std::env::VarError),
     #[error("Failed regex operation : {0}")]
     InvalidRegex(regex::Error),
     #[error("Invalid formula : {0}")]
@@ -147,3 +149,9 @@ impl From <csv::Error> for RadError {
         Self::CsvError(err)
     }
 }
+
+impl From <std::env::VarError> for RadError {
+    fn from(err : std::env::VarError) -> Self {
+        Self::EnvError(err)
+    }
+}
