@@ -1,7 +1,7 @@
 use std::io::{self, Write};
 use std::collections::HashMap;
 use std::fs::File;
-use std::path::Path;
+use std::path::{Path, PathBuf};
 use crate::error::{RadError, ErrorLogger};
 use crate::models::{MacroMap, WriteOption, UnbalancedChecker, MacroRule};
 use crate::utils::Utils;
@@ -16,6 +16,8 @@ pub struct MacroFragment {
     pub args: String,
     pub pipe: bool,
     pub greedy: bool,
+    pub preceding: bool,
+    pub yield_literal : bool,
 }
 
 impl MacroFragment {
@@ -26,6 +28,8 @@ impl MacroFragment {
             args : String::new(),
             pipe: false,
             greedy: false,
+            preceding: false,
+            yield_literal : false,
         }
     }
 
@@ -34,6 +38,8 @@ impl MacroFragment {
         self.name.clear();
         self.args.clear();
         self.pipe = false; 
+        self.greedy = false; 
+        self.yield_literal = false;
     }
 
     pub fn is_empty(&self) -> bool {
@@ -59,6 +65,8 @@ pub struct Processor{
     pub newline: String,
     pub paused: bool,
     purge: bool,
+    always_greedy: bool,
+    pub temp_target: PathBuf,
 }
 // 1. Get string
 // 2. Parse until macro invocation detected
@@ -79,8 +87,13 @@ impl Processor {
             pipe_value: String::new(),
             paused: false,
             purge: false,
+            always_greedy: false,
+            temp_target: PathBuf::from(std::env::temp_dir()).join("rad.txt"),
         }
     }
+    pub fn set_greedy(&mut self) {
+        self.always_greedy = true;
+    }
     pub fn set_purge(&mut self) {
         self.purge = true;
     }
@@ -262,9 +275,12 @@ impl Processor {
                                         self.ch_number
                                     );
                             }
-                            if ch == '|' {frag.pipe = true; }
-                            else if ch == '+' { frag.greedy = true; }
-                            else { frag.name.push(ch); }
+                            match ch {
+                                '|' => frag.pipe = true,
+                                '+' => frag.greedy = true,
+                                '*' => frag.yield_literal = true,
+                                _ => frag.name.push(ch) 
+                            }
                         },
                         Cursor::Arg => {
                             frag.args.push(ch)
@@ -288,7 +304,7 @@ impl Processor {
                     } 
                     // Invoke macro
                     else {
-                        if let Some(content) = self.evaluate(level, caller, &frag.name, &frag.args, frag.greedy)? {
+                        if let Some(mut content) = self.evaluate(level, caller, &frag.name, &frag.args, frag.greedy || self.always_greedy)? {
                             if frag.pipe {
                                 self.pipe_value = content;
                                 lexor.escape_nl = true;
@@ -298,6 +314,9 @@ impl Processor {
                             else if content.len() == 0 {
                                 lexor.escape_nl = true;
                             } else {
+                                if frag.yield_literal {
+                                    content = format!("\\*{}*\\", content);
+                                }
                                 remainder.push_str(&content);
                             }
                         } 
@@ -346,7 +365,8 @@ impl Processor {
     }
 
     // Evaluate can be nested deeply
-    fn evaluate(&mut self,level: usize, caller: &str, name: &str, args: &String, greedy: bool) -> Result<Option<String>, RadError> {
+    // Disable caller for temporary
+    fn evaluate(&mut self,level: usize, _caller: &str, name: &str, args: &String, greedy: bool) -> Result<Option<String>, RadError> {
         let level = level + 1;
         // This parses and processes arguments
         // and macro should be evaluated after
@@ -354,14 +374,20 @@ impl Processor {
         // Make caller to name
         let args = self.parse_chunk(level, name, args)?; 
 
-        // Find Local macro first
-        if let Some(local) = self.map.local.get(&Utils::local_name(level, &caller, &name)) {
-            return Ok(Some(local.to_owned()))
-        } 
+        // Find local macro
+        // The macro can be be the macro defined in parent macro
+        let mut temp_level = level;
+        while temp_level > 0 {
+            if let Some(local) = self.map.local.get(&Utils::local_name(temp_level, &name)) {
+                return Ok(Some(local.to_owned()));
+            } 
+            temp_level = temp_level - 1;
+        }
+        println!("Find other");
         // Find custom macro
         // custom macro comes before basic macro so that
         // user can override it
-        else if self.map.custom.contains_key(name) {
+        if self.map.custom.contains_key(name) {
             if let Some(result) = self.invoke_rule(level, name, &args, greedy)? {
                 return Ok(Some(result));
             } else {
@@ -396,7 +422,7 @@ impl Processor {
 
         for (idx, arg_type) in arg_types.iter().enumerate() {
             //Set arg to be substitued
-            self.map.new_local(level + 1, name, arg_type ,&args[idx]);
+            self.map.new_local(level + 1, arg_type ,&args[idx]);
         }
         // parse the Chunk
         let result = self.parse_chunk(level, &name, &rule.body)?;
@@ -521,7 +547,6 @@ impl DefineParser {
                     } 
                     // Go to body
                     else if ch == '=' {
-                        println!("GO TO BODY");
                         self.args.push_str(&self.container);
                         self.container.clear();
                         self.arg_cursor = DefineCursor::Body; 
